using System;
using System.Data;
using System.Data.SqlClient;
using System.Collections.Generic;
using System.Text;


namespace AW.Portal.Data {

	public class DataLayer {

		public DataLayer(string connectionString) {
			this._connectionString = connectionString;
		}


		private string _connectionString = string.Empty;
		public string ConnectionString {
			get {
				return this._connectionString;
			}
		}

		#region HR Data Access Methods (ListDepartments, ListEmployeesByDepartment, GetEmployeeDetails, ListJobCandidates, GetJobCandidate)

		public List<Department> ListDepartments() {
			return GetDataItems<Department>(SQL.ListDepartments, null, null);
		}

		public List<Employee> ListEmployeesByDepartment(int departmentID) {
			return GetDataItems<Employee>(SQL.ListEmployeesByDepartment, new string[] { "@departmentID" }, new object[] { departmentID });
		}

		public Employee GetEmployeeDetails(int employeeID) {
			return GetDataItem<Employee>(SQL.GetEmployeeDetails, new string[] { "@employeeID" }, new object[] { employeeID });
		}

		public List<Candidate> ListJobCandidates() {
			return GetDataItems<Candidate>(SQL.ListJobCandidates, null, null);
		}

		public Candidate GetJobCandidate(int candidateID) {
			return GetDataItem<Candidate>(SQL.GetJobCandidate, new string[] { "@candidateID" }, new object[] { candidateID });
		}

		#endregion


		#region Data Helpers (GetDataItem, GetDataItems)

		private T GetDataItem<T>(string commandText, string[] parameterNames, object[] parameterValues)
			where T : IBusinessEntity, new() {

			SqlConnection cnn = new SqlConnection(this.ConnectionString);
			SqlCommand cmd = new SqlCommand();
			cmd.CommandType = CommandType.Text;
			cmd.Connection = cnn;
			cmd.CommandText = commandText;

			if (parameterNames != null && parameterNames.Length > 0) {
				for (int i = 0; i < parameterNames.Length; i++) {
					cmd.Parameters.AddWithValue(parameterNames[i], parameterValues[i]);
				}
			}

			T dataItem = new T();
			using (SqlDataReader reader = cmd.ExecuteReader()) {
				if (reader != null) {
					reader.Read();
					dataItem.Fill(reader);
				}
			}

			return dataItem;
		}


		private List<T> GetDataItems<T>(string commandText, string[] parameterNames, object[] parameterValues)
			where T : IBusinessEntity, new() {

			SqlConnection cnn = new SqlConnection(this.ConnectionString);
			SqlCommand cmd = new SqlCommand();
			cmd.CommandType = CommandType.Text;
			cmd.Connection = cnn;
			cmd.CommandText = commandText;

			if (parameterNames != null && parameterNames.Length > 0) {
				for (int i = 0; i < parameterNames.Length; i++) {
					cmd.Parameters.AddWithValue(parameterNames[i], parameterValues[i]);
				}
			}

			List<T> dataItems = new List<T>();
			using (SqlDataReader reader = cmd.ExecuteReader()) {
				if (reader != null) {
					while (reader.Read()) {
						T dataItem = new T();
						dataItem.Fill(reader);
						dataItems.Add(dataItem);
					}

				}
			}

			return dataItems;
		}

		#endregion

	}
}
