using System;


namespace AW.Portal.Data {
    
    public static class SQL {

		public static readonly string GetDepartment = @"
            SELECT dept.DepartmentID, DepartmentName = dept.[Name], GroupName, 
				EmployeeCount = (SELECT COUNT(hist.EmployeeID) as EmployeeCount
				FROM HumanResources.EmployeeDepartmentHistory hist
				WHERE hist.DepartmentID = dept.DepartmentID
				AND hist.EndDate IS NULL)
				FROM HumanResources.Department dept
				WHERE dept.DepartmentID = @departmentID";
		
		public static readonly string ListDepartments = @"
            SELECT dept.DepartmentID, DepartmentName = dept.[Name], GroupName, 
				EmployeeCount = (SELECT COUNT(hist.EmployeeID) as EmployeeCount
				FROM HumanResources.EmployeeDepartmentHistory hist
				WHERE hist.DepartmentID = dept.DepartmentID
				AND hist.EndDate IS NULL)
			FROM HumanResources.Department dept
			ORDER BY GroupName, DepartmentName";

		public static readonly string ListEmployees = @"
            SELECT e.EmployeeID, p.FirstName, p.LastName, e.Title as JobTitle
            FROM HumanResources.Employee e, 
                HumanResources.EmployeeDepartmentHistory hist, 
                Person.Contact p
            WHERE hist.EmployeeID = e.EmployeeID
            AND p.ContactID = e.ContactID
            AND e.CurrentFlag = 1
			ORDER BY hist.DepartmentID, p.LastName";

		public static readonly string ListEmployeesByDepartment = @"
            SELECT e.EmployeeID, p.FirstName, p.LastName, e.Title as JobTitle
            FROM HumanResources.Employee e, 
                HumanResources.EmployeeDepartmentHistory hist, 
                Person.Contact p
            WHERE hist.EmployeeID = e.EmployeeID
            AND p.ContactID = e.ContactID
            AND hist.DepartmentID = @departmentID
            AND e.CurrentFlag = 1
			ORDER BY p.LastName";

		public static readonly string GetEmployeeDetails = @"
            SELECT e.EmployeeID, p.FirstName, p.LastName, e.Title as JobTitle,
                AddressLine1, AddressLine2, City, sp.[Name], PostalCode
            FROM HumanResources.Employee e, 
                HumanResources.EmployeeDepartmentHistory hist,
                HumanResources.Department dept,
                Person.Contact p,
                HumanResources.EmployeeAddress ea,
                Person.Address a,
                Person.StateProvince sp
            WHERE hist.EmployeeID = e.EmployeeID
            AND hist.DepartmentID = dept.DepartmentID
            AND p.ContactID = e.ContactID
            AND ea.EmployeeID = e.EmployeeID
            AND a.AddressID = ea.AddressID
            AND a.StateProvinceID = sp.StateProvinceID
            AND e.EmployeeID = @employeeID";

		public static readonly string ListJobCandidates = @"
			SELECT JobCandidateID, Resume.query('
			declare namespace ns=""http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/Resume""; 
			data(/ns:Resume/ns:Name/*)') as CandidateName,
			Resume.query('
			declare namespace ns=""http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/Resume""; 
			data(/ns:Resume/ns:Skills)') as Skills
			FROM HumanResources.JobCandidate
			WHERE EmployeeID IS NULL";

		public static readonly string GetJobCandidate = @"
            SELECT JobCandidateID, Resume.query('
            declare namespace ns=""http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/Resume""; 
            data(/ns:Resume/ns:Name/*)') as CandidateName,
            Resume.query('
            declare namespace ns=""http://schemas.microsoft.com/sqlserver/2004/07/adventure-works/Resume""; 
            data(/ns:Resume/ns:Skills)') as Skills
            FROM HumanResources.JobCandidate
            WHERE JobCandidateID = @candidateID";

    }
}
