using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.ComponentModel;


namespace WebPartTests {

    public class FavoritesWebPart : WebPart, IPersonalizable {

        public FavoritesWebPart() { }

        private List<string> _hyperlinks;
        [Personalizable]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Content)]
        public List<string> Hyperlinks {
            get { 
                if( _hyperlinks == null )
                    _hyperlinks = new List<string>();

                return _hyperlinks; 
            }
            set { _hyperlinks = value; }
        }


        bool _isDirty = false;
        public bool IsDirty {
            get { return _isDirty; }
        }


        


        public void AddHyperlink(string hyperlink) {
            _isDirty = true;
            this.Hyperlinks.Add(hyperlink);
        }


        protected override void CreateChildControls() {

            this.Controls.Clear();

            if (DesignMode) return;

            foreach (string link in this.Hyperlinks) {

                if (this.WebPartManager.DisplayMode == WebPartManager.DesignDisplayMode ||
                    this.WebPartManager.DisplayMode == WebPartManager.EditDisplayMode) {
                   
                    LinkButton btn = new LinkButton();
                    btn.CommandArgument = link;
                    btn.CommandName = "link";
                    btn.Page = this.Page;
                    btn.Text = "[ Remove ]";
                    btn.Click += new EventHandler(btn_Click);

                    this.Controls.Add(btn);

                    this.Controls.Add(new LiteralControl("&nbsp;"));
                }

                HyperLink hyperlink = new HyperLink();
                hyperlink.Text = link;
                hyperlink.NavigateUrl = link;
                this.Controls.Add(hyperlink);

                this.Controls.Add( new LiteralControl("<br />") );
            }
        }

        void btn_Click(object sender, EventArgs e) {

            LinkButton btn = sender as LinkButton;

            if (btn != null) {
                
                if (this.Hyperlinks.Contains(btn.CommandArgument)) {
                    _isDirty = true;
                    this.Hyperlinks.Remove(btn.CommandArgument);
                    this.CreateChildControls();
                }
            }
        }


        public override void RenderControl(HtmlTextWriter writer) {
            if (DesignMode) {
                writer.Write("Hyperlink A");
                writer.Write("Hyperlink B");
                writer.Write("Hyperlink C");
                return;
            } else {
                base.RenderControl(writer);
            }
        }
       
        
        public new void Load(PersonalizationDictionary state) {

            PersonalizationEntry pe = state["Hyperlinks"] as PersonalizationEntry;

            if (pe != null) {
                this.Hyperlinks = (List<string>) pe.Value;
            }
        }

        public void Save(PersonalizationDictionary state) {

            PersonalizationEntry entry =
                new PersonalizationEntry(this.Hyperlinks, this.WebPartManager.Personalization.Scope);
            state["Hyperlinks"] = entry;
        }

    }
}