using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.WebControls;
using System.Security.Cryptography;

namespace AW.Portal.Web.SharedWebParts {

    public class TaskNotes : WebPart, IPersonalizable {

        private string _message;
        public string Message {
            get { return _message; }
            set { _message = value; }
        }

        private Label _lbl;
        private TextBox _tb;


        public bool IsEditing {
            get {
                return Convert.ToBoolean(this.ViewState["IsEditing"]);
            }
            set { this.ViewState["IsEditing"] = value; }
        }


        protected override void CreateChildControls() {
            base.CreateChildControls();

            this._lbl = new Label();
            this.Controls.Add(_lbl);

            this._tb = new TextBox();
            this._tb.Visible = this.IsEditing;
            this._tb.TextMode = TextBoxMode.MultiLine;
            this._tb.Rows = 10;
            this._tb.Columns = 40;
            this.Controls.Add(_tb);
        }


        protected override void Render(System.Web.UI.HtmlTextWriter writer) {

            this._tb.Visible = this.IsEditing;
            this._lbl.Visible = !this.IsEditing;

            if (this.IsEditing) {
                this._tb.Text = this.Message;
                this._lbl.Text = "";
            } else {
                this._tb.Text = "";
                this._lbl.Text = this.Message;
            }

            base.Render(writer);
        }


        public override WebPartVerbCollection Verbs {
            get {
                List<WebPartVerb> verbs = new List<WebPartVerb>();
                EditNoteVerb verb = null;

                WebPartManager wpm = WebPartManager.GetCurrentWebPartManager(this.Page);

                if (this.IsEditing) {
                    verb = new EditNoteVerb("Save Note", SaveNoteHandler);
                } else {
                    verb = new EditNoteVerb("Edit Note", EditNoteHandler);
                }

                if (verb != null) {
                    verbs.Add(verb);
                }

                return new WebPartVerbCollection(verbs); ;
            }
        }


        void EditNoteHandler(object sender, WebPartEventArgs e) {
            this.IsEditing = true;
        }

        void SaveNoteHandler(object sender, WebPartEventArgs e) {

            this.Message = this._tb.Text;
            this._isDirty = true;
            this.IsEditing = false;

        }


        private bool _isDirty = false;
        public bool IsDirty {
            get { return _isDirty; }
        }


        public new virtual void Load(PersonalizationDictionary state) {

            PersonalizationEntry pe = state["Message"] as PersonalizationEntry;

            if (pe != null) {
                try {
                    string data = pe.Value.ToString();
                    string message = EncryptionHelpers.DecryptData(data);
                    this.Message = message;
                } catch (CryptographicException ex) {
                    this.Message = ex.Message;
                }
            }
        }

        public void Save(PersonalizationDictionary state) {

            if (this.WebPartManager != null) {

                string data = EncryptionHelpers.EncryptData(_message);

                PersonalizationEntry entry =
                    new PersonalizationEntry(data, PersonalizationScope.User);
                state["Message"] = entry;
            }
        }



        internal class EditNoteVerb : WebPartVerb {
            public EditNoteVerb(string verbText, WebPartEventHandler handler)
                : base("EditNoteVerb", handler) {
                this.Text = verbText;
            }
        }

    }
}
