using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Collections.Generic;
using System.IO;
using System.Xml;


namespace AW.Portal.Web {

    public class CentralGalleryCatalogPart : CatalogPart {


        static CentralGalleryCatalogPart() {
            WebPartDescription[] designParts = new WebPartDescription[3];
            designParts[0] = new WebPartDescription("Part1", "WebPart 1", null, null);
            designParts[1] = new WebPartDescription("Part2", "WebPart 2", null, null);
            designParts[2] = new WebPartDescription("Part3", "WebPart 3", null, null);
            CentralGalleryCatalogPart.DesignModeAvailableWebParts = new WebPartDescriptionCollection(designParts);
        }


        private static WebPartDescriptionCollection DesignModeAvailableWebParts;

        public override string Title {
            get {
                string title = base.Title;
                return string.IsNullOrEmpty(title) ?
                    "Central Gallery" : title;
            }
            set {
                base.Title = value;
            }
        }


        private static string _galleryPath = "~/CentralGallery/";
        [Personalizable(PersonalizationScope.Shared)]
        [WebBrowsable(true)]
        public virtual string GalleryPath {
            get {
                return string.IsNullOrEmpty(_galleryPath) ? "~/CentralGallery/" : _galleryPath;
            }
            set {
                if (!value.EndsWith("/"))
                    value += "/";

                _galleryPath = value;
            }
        }


        public override WebPartDescriptionCollection GetAvailableWebPartDescriptions() {

            if (base.DesignMode) {
                return CentralGalleryCatalogPart.DesignModeAvailableWebParts;
            }

            List<WebPartDescription> coll = new List<WebPartDescription>();

            string path = HttpContext.Current.Server.MapPath(this.GalleryPath);

            foreach (string file in Directory.GetFiles(path)) {
                if (file.EndsWith(".WebPart")) {
                    string partTitle = Path.GetFileNameWithoutExtension(file);
                    WebPart wp = GetWebPart(partTitle);
                    wp.ID = partTitle;
                    coll.Add(new WebPartDescription(wp));
                }
            }
            return new WebPartDescriptionCollection(coll);
        }



        public static void ImportWebPart(string partTitle, string partContent) {

            string path = _galleryPath + partTitle + ".WebPart";
            path = HttpContext.Current.Server.MapPath(path);
            File.WriteAllText(path, partContent);
        }



        public override WebPart GetWebPart(WebPartDescription description) {
            return GetWebPart(description.Title);
        }


        public virtual WebPart GetWebPart(string partTitle) {

            string path = _galleryPath + partTitle + ".WebPart";
            path = HttpContext.Current.Server.MapPath(path);

            WebPart wp = null;

            using (FileStream fs = File.OpenRead(path)) {
                XmlTextReader reader = new System.Xml.XmlTextReader(fs);
                string errorMessage = "";
                wp = WebPartManager.ImportWebPart(reader, out errorMessage);
            }

            return wp;
        }

    }
}