using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;


namespace AW.Portal.Web {

    public class CollapsibleEditorPartChrome : EditorPartChrome {


        public CollapsibleEditorPartChrome(EditorZoneBase zone) : base(zone) { }

        CollapsibleEditorZone EditorZone {
            get {
                return (CollapsibleEditorZone)this.Zone;
            }
        }


        public override void RenderEditorPart(HtmlTextWriter writer, EditorPart editorPart) {

            if (editorPart == null) {
                throw new ArgumentNullException("editorPart");
            }

            PartChromeType chromeType = this.Zone.GetEffectiveChromeType(editorPart);
            Style style = this.CreateEditorPartChromeStyle(editorPart, chromeType);

            if (!style.IsEmpty) {
                style.AddAttributesToRender(writer, this.Zone);
            }


            if ((chromeType == PartChromeType.TitleAndBorder) || (chromeType == PartChromeType.TitleOnly)) {
                this.RenderTitle(writer, editorPart);
            }

            if (editorPart.ChromeState != PartChromeState.Minimized) {
                Style style2 = this.Zone.PartStyle;
                if (!style2.IsEmpty) {
                    style2.AddAttributesToRender(writer, this.Zone);
                }


                writer.AddAttribute("id", "EditorPartBody_" + editorPart.ClientID);
                if (this.EditorZone.EditorPartsAdded) {
                    writer.AddStyleAttribute("display", "none");
                }
                writer.RenderBeginTag(HtmlTextWriterTag.Div);
                this.RenderPartContents(writer, editorPart);
                writer.RenderEndTag();

                this.EditorZone.EditorPartsAdded = true;
            }
        }


        protected virtual void RenderTitle(HtmlTextWriter writer, EditorPart editorPart) {

            HttpContext ctx = HttpContext.Current;
            string imageID = string.Format("EditorPartImage_{0}", editorPart.ClientID);
            string expandImageUrl = "Images/Expand.gif";
            string minimizeImageUrl = "Images/Minimize.gif";

            string javascript = string.Format(
                "ToggleEditorDisplay('EditorPartBody_{0}', '{1}', '{2}', '{3}')",
                editorPart.ClientID,
                imageID,
                expandImageUrl,
                minimizeImageUrl
                );

            Style style2 = this.Zone.PartTitleStyle;
            if (!style2.IsEmpty) {
                style2.AddAttributesToRender(writer, this.Zone);
            }

            writer.RenderBeginTag(HtmlTextWriterTag.Div);

            writer.AddAttribute("onclick", javascript);
            writer.AddStyleAttribute(HtmlTextWriterStyle.Cursor, "hand");
            writer.AddAttribute("src", this.EditorZone.EditorPartsAdded ? expandImageUrl : minimizeImageUrl);
            writer.AddAttribute("id", imageID);
            writer.RenderBeginTag(HtmlTextWriterTag.Img);
            writer.RenderEndTag();

            writer.Write(editorPart.Title);
            writer.RenderEndTag();
        }
    }
}