using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Collections.Generic;
using System.ComponentModel;
using System.Resources;
using System.Reflection;

namespace AW.Portal.Web {

    public class FavoritesWebPart : WebPart, IPersonalizable {

        public FavoritesWebPart() { }

        bool _sorted = false;


        public override string Title {
            get {
                return (string.IsNullOrEmpty(base.Title)) ? "My Favourites" : base.Title;
            }
            set {
                base.Title = value;
            }
        }


        public override string Description {
            get {
                return (string.IsNullOrEmpty(base.Description)) ? "Favorites Web Part" : base.Description;
            }
            set {
                base.Description = value;
            }
        }


        private bool _displayDescriptions;
        [WebBrowsable]
        [Personalizable]
        public bool DisplayDescriptions {
            get { return _displayDescriptions; }
            set { _displayDescriptions = value; }
        }



        private List<HyperlinkData> _hyperlinks = new List<HyperlinkData>();
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Content)]
        public List<HyperlinkData> Hyperlinks {
            get { return _hyperlinks; }
            set {
                _hyperlinks = value;
            }
        }



        public void AddHyperlink(HyperlinkData hyperlink) {

            this.SetPersonalizationDirty();
            _isDirty = true;
            _sorted = false;
            this.Hyperlinks.Add(hyperlink);

            CreateChildControls();
        }



        public void RemoveHyperlink(string url) {

            List<HyperlinkData> deleteableLinks = new List<HyperlinkData>();

            foreach (HyperlinkData link in this.Hyperlinks) {
                if (link.URL == url) {
                    deleteableLinks.Add(link);
                }
            }

            if (deleteableLinks.Count > 0) {
                this.SetPersonalizationDirty();
                _isDirty = true;
                _sorted = false;

                foreach (HyperlinkData link in deleteableLinks) {
                    if (link.URL == url) {
                        this.Hyperlinks.Remove(link);
                    }
                }

                CreateChildControls();
            }
        }


        bool _isDirty = false;
        public bool IsDirty {
            get { return _isDirty; }
        }


        protected override void CreateChildControls() {

            this.Controls.Clear();

            if (!_sorted) {
                this.Hyperlinks.Sort(new HyperlinkComparer());
                _sorted = true;
            }


            foreach (HyperlinkData linkData in this.Hyperlinks) {

                if (this.DisplayDescriptions && !string.IsNullOrEmpty(linkData.Description)) {
                    this.Controls.Add(new LiteralControl("<p>"));
                    DisplayHyperlink(linkData);
                    DisplayDescription(linkData);
                    this.Controls.Add(new LiteralControl("</p>"));
                } else {
                    DisplayHyperlink(linkData);
                }
            }
        }


        public override void RenderControl(HtmlTextWriter writer) {
            base.RenderControl(writer);
        }


        public new void Load(PersonalizationDictionary state) {

            PersonalizationEntry pe = state["Hyperlinks"] as PersonalizationEntry;

            if (pe != null) {
                this.Hyperlinks = (List<HyperlinkData>)pe.Value;
            }
        }

        public void Save(PersonalizationDictionary state) {

            if (this.Page != null) {

                WebPartManager wpm = WebPartManager.GetCurrentWebPartManager(this.Page);

                if (wpm != null) {

                    PersonalizationEntry entry =
                        new PersonalizationEntry(this.Hyperlinks, wpm.Personalization.Scope);
                    state["Hyperlinks"] = entry;
                }
            }
        }



        public override EditorPartCollection CreateEditorParts() {

            FavoritesEditorPart editorPart = new FavoritesEditorPart();
            editorPart.ID = this.ID + "_addLinkPart";
            editorPart.Title = "Add New Link";


            EditorPartCollection parts =
              new EditorPartCollection(new EditorPart[] { editorPart });

            return parts;
        }


        private void DisplayDescription(HyperlinkData linkData) {
            this.Controls.Add(
                        new LiteralControl(
                        string.Format(
                            "<small>{0}</small>",
                            linkData.Description
                            )
                        )
                    );
        }

        private void DisplayHyperlink(HyperlinkData linkData) {

            if (this.WebPartManager.DisplayMode == WebPartManager.EditDisplayMode) {

                ImageButton btnRemove = new ImageButton();
                btnRemove.CommandArgument = linkData.URL;
                btnRemove.Click += new ImageClickEventHandler(btnRemove_Click);
                btnRemove.ImageUrl = "~/Images/Delete.gif";
                btnRemove.AlternateText = "Remove this link";
                this.Controls.Add(btnRemove);

                this.Controls.Add(new LiteralControl("&nbsp;"));
            }

            HyperLink hyperlink = new HyperLink();
            hyperlink.Text = linkData.DisplayName;
            hyperlink.NavigateUrl = linkData.URL;
            this.Controls.Add(hyperlink);
            this.Controls.Add(new LiteralControl("<br />"));
        }


        void btnRemove_Click(object sender, ImageClickEventArgs e) {

            ImageButton btn = (ImageButton)sender;
            this.RemoveHyperlink(btn.CommandArgument);
        }


        private HyperlinkData GetHyperlinkByUrl(string url) {
            foreach (HyperlinkData link in this.Hyperlinks) {
                if (link.URL == url) {
                    return link;
                }
            }
            return null;
        }


        internal class HyperlinkComparer : IComparer<HyperlinkData> {
            public int Compare(HyperlinkData x, HyperlinkData y) {
                return x.DisplayName.CompareTo(y.DisplayName);
            }
        }

    }

}