using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Diagnostics;

namespace AW.Portal.Web {

    public class PortalWebPartManager : WebPartManager {

        public PortalWebPartManager() { }


        public bool IsRevisionPage {
            get {
                return Page.Request.Params["view"] == "edit";
            }
        }


        private bool _hasUnapprovedChanges;
        public bool HasUnapprovedChanges {
            get { return _hasUnapprovedChanges; }
            set { _hasUnapprovedChanges = value; }
        }


        private bool _committingChanges = false;
        public bool CommittingChanges {
            get { return _committingChanges; }
            set { _committingChanges = value; }
        }


        public void CommitChanges() {
            this.CommittingChanges = true;
            SetPersonalizationDirty();
        }


        protected override void OnAuthorizeWebPart(WebPartAuthorizationEventArgs e) {

            if (string.IsNullOrEmpty(e.AuthorizationFilter)) {
                e.IsAuthorized = true;
                return;
            }

            string[] authorizedRoles =
                e.AuthorizationFilter.Split(new char[] { ',' });

            for (int i = 0; i < authorizedRoles.Length; i++) {
                if (IsUserInRole(authorizedRoles[i])) {
                    e.IsAuthorized = true;
                    return;
                }
            }
            e.IsAuthorized = false;
        }



        bool IsUserInRole(string roleName) {
            if (Roles.Enabled) {
                return Roles.IsUserInRole(roleName);
            } else {
                return Context.User.IsInRole(roleName);
            }
        }

    }
}