using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Collections.ObjectModel;
using System.Web.Compilation;

namespace AW.Portal.Web {

    public class PortalWebPartZone : WebPartZone {

        protected override bool HasHeader {
            get { return true; }
        }


        protected override void RenderHeader(HtmlTextWriter writer) {

            HtmlInputButton b = new HtmlInputButton();
            b.ID = "mybutton1";
            b.Value = "Add To This Zone";

            ClientScriptManager cs = this.Page.ClientScript;
            string postbackReference = cs.GetPostBackEventReference(
                this,
                "catalog:[[WEBPART]]"
                );

            b.Attributes.Add(
                "onclick",
                string.Format(
                    "DisplayDialog(\"CatalogDialog.aspx?postbackReference={0}\")",
                    postbackReference
                    )
                );

            b.RenderControl(writer);
            writer.WriteBreak();

        }


        protected override void OnCreateVerbs(WebPartVerbsEventArgs e) {
            base.OnCreateVerbs(e);

            this.EditVerb.Visible = false;
            Collection<WebPartVerb> verbs = new Collection<WebPartVerb>();

            HttpContext ctx = HttpContext.Current;
            
            if (ctx.Request.IsAuthenticated) {

                WebPartVerb editVerb = new WebPartVerb(
                    "editVerb", 
                    new WebPartEventHandler(HandleEditClick)
                    );

                verbs.Add(editVerb);

                if (this.WebPartManager.Personalization.Scope == PersonalizationScope.Shared) {
                    editVerb.Text = "Edit Shared Web Part";
                } else {
                    editVerb.Text = "Edit Web Part";
                }
               
            }
            e.Verbs = new WebPartVerbCollection(verbs);
        }


        protected override void RaisePostBackEvent(string eventArgument) {

            WebPartManager wpm = WebPartManager.GetCurrentWebPartManager(this.Page);

            if (eventArgument.StartsWith("catalog:")) {

                try {
                    string[] argParts = eventArgument.Split(new char[] { ':' }, StringSplitOptions.RemoveEmptyEntries);
                    Type t = BuildManager.GetType(argParts[argParts.Length - 1], true, true);
                    WebPart wp1 = (WebPart)Activator.CreateInstance(t);

                    wpm.AddWebPart(wp1, this, this.WebParts.Count);
                } catch (Exception ex) {
                    Console.WriteLine(ex.Message);
                }
            } else {
                base.RaisePostBackEvent(eventArgument);
            }
        }


        void HandleEditClick(object sender, WebPartEventArgs e) {

            WebPart wp = e.WebPart;

            if (wp != this.WebPartManager.SelectedWebPart) {
                this.WebPartManager.DisplayMode = WebPartManager.EditDisplayMode;
                this.WebPartManager.BeginWebPartEditing(wp);
            }
        }



        void HandleConnectClick(object sender, WebPartEventArgs e) {

            WebPart wp = e.WebPart;

            if (wp != this.WebPartManager.SelectedWebPart) {
                this.WebPartManager.DisplayMode = WebPartManager.ConnectDisplayMode;
                this.WebPartManager.BeginWebPartConnecting(wp);
            }
        }
    }
}