using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using AW.Portal.Web;

namespace AW.Portal.Web {

    public class VersionedPersonalizationProvider : SqlPersonalizationProvider {

        public VersionedPersonalizationProvider() { }



        protected override void LoadPersonalizationBlobs(
            WebPartManager wpm,
            string path,
            string userName,
            ref byte[] sharedDataBlob,
            ref byte[] userDataBlob) {

            PersonalizationStateQuery query = new PersonalizationStateQuery();
            query.PathToMatch = path + "|revision";

            bool pageHasRevisionData =
                GetCountOfState(PersonalizationScope.Shared, query) > 0;

            bool isRevisionPage = ((PortalWebPartManager)wpm).IsRevisionPage;
            ((PortalWebPartManager)wpm).HasUnapprovedChanges
                = pageHasRevisionData;

            if (isRevisionPage && pageHasRevisionData) {
                path += "|revision";
            }

            base.LoadPersonalizationBlobs(
                wpm,
                path,
                userName,
                ref sharedDataBlob,
                ref userDataBlob
            );
        }


        protected override void ResetPersonalizationBlob(WebPartManager wpm, string path, string userName) {
            base.ResetPersonalizationBlob(wpm, path, userName);
        }


        protected override void SavePersonalizationBlob(
            WebPartManager wpm,
            string path,
            string userName,
            byte[] dataBlob) {

            bool isRevisionPage =
                ((PortalWebPartManager)wpm).IsRevisionPage;

            if (((PortalWebPartManager)wpm).CommittingChanges) {

                base.SavePersonalizationBlob(
                    wpm, path, userName, dataBlob);

                ResetPersonalizationBlob(
                    wpm, path + "|revision", null);

            } else if (isRevisionPage) {

                base.SavePersonalizationBlob(
                    wpm,
                    path + "|revision",
                    userName,
                    dataBlob);

            } else {
                base.SavePersonalizationBlob(
                    wpm,
                    path,
                    userName,
                    dataBlob);
            }
        }

    }
}